"""
System prompts for zwarm agents.
"""

from zwarm.prompts.orchestrator import ORCHESTRATOR_SYSTEM_PROMPT, get_orchestrator_prompt

__all__ = [
    "ORCHESTRATOR_SYSTEM_PROMPT",
    "get_orchestrator_prompt",
]
